//Set working directory if necessary
//cd "..."


////////////////
//Prepare data
////////////////

//Load DICEU data 
import excel "./Datasets/deu_positions_in_diceu.xlsx", sheet("Tabelle1") firstrow clear
drop I

//Manipulate data for merging
replace Actor = trim(Actor)
rename Actor government
rename Issue n_issue

//Merge data with DEU data
merge m:1 government n_issue using "./Datasets/deu_data_long.dta"
drop _merge

//Drop observations not needed
drop if government == "aldepty"
drop if government == "ep"
drop if government == "greenpty"
drop if government == "guepty"
drop if government == "epppty"
drop if government == "pespty"
drop if government == "uenpty"
drop if government == "OUTCOME"
drop if government == "reference"
drop if position == .

//Recode both DEU and DICEU positions on DEU scale
rename DEUposition DEU_position_DICEU
rename position DEU_position_DEU
label variable DEU_position_DICEU "Position from DICEU videos on DEU scale"
label variable DEU_position_DEU "Position from DEU expert interviews on DEU scale"
drop if government == ""

//Drop issues not covered in DICEU
egen check_issue = max(DEU_position_DICEU), by(n_issue)
keep if check_issue != .

//Where position on videos is between two DEU scale points, assign midpoint between the two positions
replace DEU_position_DICEU = (DEU_position_DICEU + AlternativeDEUposition)/2 if AlternativeDEUposition != .

//Calculate distance between positions
gen distance_DEU_DICEU = abs(DEU_position_DICEU - DEU_position_DEU)
label variable distance_DEU_DICEU "Absolute difference in positions between DICEU and DEU"

//Create variable indicating the Xth position of the government on the issue
sort n_proposal n_issue government Date
by n_proposal n_issue government: gen statement_no = _n if DEU_position_DICEU != .
label variable statement_no "Indicator for Xth position on the issue"

//Create dates of Commission proposals
gen proposal_date = .
replace proposal_date = date("15/12/2005", "DMY") if n_proposal == 77
replace proposal_date = date("21/10/2005", "DMY") if n_proposal == 81
replace proposal_date = date("01/12/2005", "DMY") if n_proposal == 82
replace proposal_date = date("15/12/2005", "DMY") if n_proposal == 83
replace proposal_date = date("23/12/2005", "DMY") if n_proposal == 84
replace proposal_date = date("14/07/2006", "DMY") if n_proposal == 92
replace proposal_date = date("19/10/2006", "DMY") if n_proposal == 93
replace proposal_date = date("14/12/2006", "DMY") if n_proposal == 105
replace proposal_date = date("22/12/2006", "DMY") if n_proposal == 106
replace proposal_date = date("25/01/2007", "DMY") if n_proposal == 107
replace proposal_date = date("18/07/2006", "DMY") if n_proposal == 116
replace proposal_date = date("26/10/2006", "DMY") if n_proposal == 117
replace proposal_date = date("20/12/2007", "DMY") if n_proposal == 123
replace proposal_date = date("24/10/2005", "DMY") if n_proposal == 125
label variable proposal_date "Date of Commission proposal"

//Create variable for time lapsed since Commission proposal
gen time_lapsed = Date - proposal_date
gen time_lapsed_coarsened = 0
replace time_lapsed_coarsened = 1 if time_lapsed > 182 & time_lapsed <= 365
replace time_lapsed_coarsened = 2 if time_lapsed > 365 
label variable time_lapsed_coarsened "Time lapsed since Commission proposal"
label define time_lapsed_coarsened 0 "<6 months" 1 "6-12 months" 2 ">12 months"
label values time_lapsed_coarsened time_lapsed_coarsened


/////////////////////////////
//Cross-validation analysis
/////////////////////////////

//Calculate gross correlation and distance of DICEU and DEU positions - figures mentioned in the article
corr DEU_position_DICEU DEU_position_DEU if statement_no == 1
sum distance_DEU_DICEU if statement_no == 1

//Estimate model in TABLE 2 in the article
encode government, gen(gov)
xi: ivreg2 distance_DEU_DICEU i.time_lapsed_coarsened salience if statement_no == 1, cluster(n_issue gov) small
outreg using "./Tables/Table_2.doc", replace starlevels(5) sdec(2) se

//Predict distance if issue is highly salient and discussed within 6 months from the Commission proposal - figure mentioned in the article
margins, at(_Itime_laps_1 = 0 _Itime_laps_2 = 0 salience = 100)

//Calculate correlation for issues that are more salient and discussed within 12 months - figure mentioned in the article
corr DEU_position_DICEU DEU_position_DEU if salience > 50 & time_lapsed_c <= 1 & statement_no == 1


////////////////////////
//Missingness analysis
////////////////////////

//Create missing indicator
gen missing = 0
replace missing = 1 if DEU_position_DICEU == .
label variable missing "Binary indicator for governments with a DEU but not DICEU position"

//Create indicator for extreme positions (rescale before based on the sample)
egen minimum = min(DEU_position_DEU), by(n_issue)
egen maximum = max(DEU_position_DEU), by(n_issue)
replace DEU_position_DEU = (DEU_position_DEU - minimum)/(maximum - minimum) * 100
drop minimum maximum

gen extreme = 0 if DEU_position_DEU != .
replace extreme = 1 if DEU_position_DEU == 100
replace extreme = 1 if DEU_position_DEU == 0
label variable extreme "Binary indicator for whether DEU position is min/max DEU position in data"

//Generate variable indicating number of governments with same DEU position
egen group_value = group(n_issue DEU_position_DEU)
sort group_value
by group_value: egen count = sum(DEU_position_DEU == DEU_position_DEU)
label variable count "Number of governments with same DEU position"

//Keep only issues discussed within 12 months
egen min_time_lapsed_coarsened = min(time_lapsed_coarsened), by(n_issue)
drop if min_time_lapsed_coarsened == 2

//Estimate model in TABLE A11 in the Online appendix
logit missing extreme count salience i.n_issue if salience > 50
outreg using "./Tables/Table_A11.doc", replace starlevels(5) se

